==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDetailDescription } from "./WebColumnVisibilityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata, _super);
    function WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Column", "Unknown");
        a.item("NewValue", "Boolean");
    };
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebColumnVisibilityChangedEventArgsDetail", function () { return new WebColumnVisibilityChangedEventArgsDetailDescription(); });
        a.z("WebColumnVisibilityChangedEventArgsDetail", WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.$t = markType(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDetailDescription } from "./WebColumnVisibilityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata, _super);
    function WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Column", "Unknown");
        a.item("NewValue", "Boolean");
    };
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebColumnVisibilityChangedEventArgsDetail", function () { return new WebColumnVisibilityChangedEventArgsDetailDescription(); });
        a.ab("WebColumnVisibilityChangedEventArgsDetail", WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.$t = markType(WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata };
